@@ -34,7 +34,7 @@ namespace BibTeX
     */
     class FileImporter : public TQObject
     {
-        Q_OBJECT
+        TQ_OBJECT
     public:
         FileImporter();
         ~FileImporter();
