@@ -19,21 +19,21 @@
  ***************************************************************************/
 #include <math.h>
 
-#include <ntqstring.h>
-#include <ntqstringlist.h>
-#include <ntqregexp.h>
-#include <ntqapplication.h>
+#include <tqstring.h>
+#include <tqstringlist.h>
+#include <tqregexp.h>
+#include <tqapplication.h>
 
 #include <kdebug.h>
 #include <tdelocale.h>
 #include <tdemessagebox.h>
 #include <kprogress.h>
 
-#include <element.h>
-#include <entry.h>
-#include <file.h>
-#include <preamble.h>
-#include <macro.h>
+#include "element.h"
+#include "entry.h"
+#include "file.h"
+#include "preamble.h"
+#include "macro.h"
 #include "findduplicates.h"
 
 #define max(a,b) ((a)>(b)?(a):(b))
