@@ -17,12 +17,12 @@
  *   Free Software Foundation, Inc.,                                       *
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
-#include <ntqlayout.h>
-#include <ntqcheckbox.h>
-#include <ntqtimer.h>
-#include <ntqvalidator.h>
-#include <ntqheader.h>
-#include <ntqlabel.h>
+#include <tqlayout.h>
+#include <tqcheckbox.h>
+#include <tqtimer.h>
+#include <tqvalidator.h>
+#include <tqheader.h>
+#include <tqlabel.h>
 
 #include <kinputdialog.h>
 #include <tdelistview.h>
@@ -32,11 +32,11 @@
 #include <kdialog.h>
 #include <klineedit.h>
 
-#include <idsuggestions.h>
-#include <idsuggestionswidget.h>
-#include <settings.h>
-#include <fileimporter.h>
-#include <fileimporterbibtex.h>
+#include "idsuggestions.h"
+#include "idsuggestionswidget.h"
+#include "settings.h"
+#include "fileimporter.h"
+#include "fileimporterbibtex.h"
 #include "settingsidsuggestions.h"
 
 namespace KBibTeX
