@@ -31,7 +31,7 @@ namespace KBibTeX
 {
     class SettingsSearchURL : public TQWidget
     {
-        Q_OBJECT
+        TQ_OBJECT
     public:
         SettingsSearchURL( TQWidget *parent = 0, const char *name = 0 );
         ~SettingsSearchURL();
