@@ -40,7 +40,7 @@ namespace KBibTeX
 
     class WebQueryCiteSeerXWidget : public WebQueryWidget
     {
-        Q_OBJECT
+        TQ_OBJECT
 
     public:
         WebQueryCiteSeerXWidget( TQWidget *parent, const char *name = 0 );
@@ -58,7 +58,7 @@ namespace KBibTeX
 
     class WebQueryCiteSeerX : public WebQuery
     {
-        Q_OBJECT
+        TQ_OBJECT
 
     public:
 
